Class: Google::Apis::PrivatecaV1::Certificate
- Inherits:
-
Object
- Object
- Google::Apis::PrivatecaV1::Certificate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/privateca_v1/classes.rb,
lib/google/apis/privateca_v1/representations.rb,
lib/google/apis/privateca_v1/representations.rb
Overview
A Certificate corresponds to a signed X.509 certificate issued by a CertificateAuthority.
Instance Attribute Summary collapse
-
#certificate_description ⇒ Google::Apis::PrivatecaV1::CertificateDescription
A CertificateDescription describes an X.509 certificate or CSR that has been issued, as an alternative to using ASN.1 / X.509.
-
#certificate_template ⇒ String
Immutable.
-
#config ⇒ Google::Apis::PrivatecaV1::CertificateConfig
A CertificateConfig describes an X.509 certificate or CSR that is to be created, as an alternative to using ASN.1.
-
#create_time ⇒ String
Output only.
-
#issuer_certificate_authority ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#lifetime ⇒ String
Required.
-
#name ⇒ String
Identifier.
-
#pem_certificate ⇒ String
Output only.
-
#pem_certificate_chain ⇒ Array<String>
Output only.
-
#pem_csr ⇒ String
Immutable.
-
#requested_not_before_time ⇒ String
Optional.
-
#revocation_details ⇒ Google::Apis::PrivatecaV1::RevocationDetails
Describes fields that are relavent to the revocation of a Certificate.
-
#subject_mode ⇒ String
Immutable.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Certificate
constructor
A new instance of Certificate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Certificate
Returns a new instance of Certificate.
548 549 550 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 548 def initialize(**args) update!(**args) end |
Instance Attribute Details
#certificate_description ⇒ Google::Apis::PrivatecaV1::CertificateDescription
A CertificateDescription describes an X.509 certificate or CSR that has been
issued, as an alternative to using ASN.1 / X.509.
Corresponds to the JSON property certificateDescription
458 459 460 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 458 def certificate_description @certificate_description end |
#certificate_template ⇒ String
Immutable. The resource name for a CertificateTemplate used to issue this
certificate, in the format projects/*/locations/*/certificateTemplates/*. If
this is specified, the caller must have the necessary permission to use this
template. If this is omitted, no template will be used. This template must be
in the same location as the Certificate.
Corresponds to the JSON property certificateTemplate
467 468 469 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 467 def certificate_template @certificate_template end |
#config ⇒ Google::Apis::PrivatecaV1::CertificateConfig
A CertificateConfig describes an X.509 certificate or CSR that is to be
created, as an alternative to using ASN.1.
Corresponds to the JSON property config
473 474 475 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 473 def config @config end |
#create_time ⇒ String
Output only. The time at which this Certificate was created.
Corresponds to the JSON property createTime
478 479 480 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 478 def create_time @create_time end |
#issuer_certificate_authority ⇒ String
Output only. The resource name of the issuing CertificateAuthority in the
format projects/*/locations/*/caPools/*/certificateAuthorities/*.
Corresponds to the JSON property issuerCertificateAuthority
484 485 486 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 484 def @issuer_certificate_authority end |
#labels ⇒ Hash<String,String>
Optional. Labels with user-defined metadata.
Corresponds to the JSON property labels
489 490 491 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 489 def labels @labels end |
#lifetime ⇒ String
Required. Immutable. The desired lifetime of a certificate. Used to create the
"not_before_time" and "not_after_time" fields inside an X.509 certificate.
Note that the lifetime may be truncated if it would extend past the life of
any certificate authority in the issuing chain.
Corresponds to the JSON property lifetime
497 498 499 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 497 def lifetime @lifetime end |
#name ⇒ String
Identifier. The resource name for this Certificate in the format projects/*/
locations/*/caPools/*/certificates/*.
Corresponds to the JSON property name
503 504 505 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 503 def name @name end |
#pem_certificate ⇒ String
Output only. The pem-encoded, signed X.509 certificate.
Corresponds to the JSON property pemCertificate
508 509 510 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 508 def pem_certificate @pem_certificate end |
#pem_certificate_chain ⇒ Array<String>
Output only. The chain that may be used to verify the X.509 certificate.
Expected to be in issuer-to-root order according to RFC 5246.
Corresponds to the JSON property pemCertificateChain
514 515 516 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 514 def pem_certificate_chain @pem_certificate_chain end |
#pem_csr ⇒ String
Immutable. A pem-encoded X.509 certificate signing request (CSR).
Corresponds to the JSON property pemCsr
519 520 521 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 519 def pem_csr @pem_csr end |
#requested_not_before_time ⇒ String
Optional. The requested not_before_time of this Certificate. This field may
only be set if the CaPool.IssuancePolicy.
allow_requester_specified_not_before_time field is set to true for the issuing
CaPool. If this field is specified, the certificate will be issued with this '
not_before_time'. If this is not specified, the 'not_before_time' will be set
to the issuance time or issuance time minus backdate_duration depending on the
CaPool configuration.
Corresponds to the JSON property requestedNotBeforeTime
530 531 532 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 530 def requested_not_before_time @requested_not_before_time end |
#revocation_details ⇒ Google::Apis::PrivatecaV1::RevocationDetails
Describes fields that are relavent to the revocation of a Certificate.
Corresponds to the JSON property revocationDetails
535 536 537 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 535 def revocation_details @revocation_details end |
#subject_mode ⇒ String
Immutable. Specifies how the Certificate's identity fields are to be decided.
If this is omitted, the DEFAULT subject mode will be used.
Corresponds to the JSON property subjectMode
541 542 543 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 541 def subject_mode @subject_mode end |
#update_time ⇒ String
Output only. The time at which this Certificate was updated.
Corresponds to the JSON property updateTime
546 547 548 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 546 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 553 def update!(**args) @certificate_description = args[:certificate_description] if args.key?(:certificate_description) @certificate_template = args[:certificate_template] if args.key?(:certificate_template) @config = args[:config] if args.key?(:config) @create_time = args[:create_time] if args.key?(:create_time) @issuer_certificate_authority = args[:issuer_certificate_authority] if args.key?(:issuer_certificate_authority) @labels = args[:labels] if args.key?(:labels) @lifetime = args[:lifetime] if args.key?(:lifetime) @name = args[:name] if args.key?(:name) @pem_certificate = args[:pem_certificate] if args.key?(:pem_certificate) @pem_certificate_chain = args[:pem_certificate_chain] if args.key?(:pem_certificate_chain) @pem_csr = args[:pem_csr] if args.key?(:pem_csr) @requested_not_before_time = args[:requested_not_before_time] if args.key?(:requested_not_before_time) @revocation_details = args[:revocation_details] if args.key?(:revocation_details) @subject_mode = args[:subject_mode] if args.key?(:subject_mode) @update_time = args[:update_time] if args.key?(:update_time) end |