Class: Google::Apis::PrivatecaV1::CertificateConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/privateca_v1/classes.rb,
lib/google/apis/privateca_v1/representations.rb,
lib/google/apis/privateca_v1/representations.rb

Overview

A CertificateConfig describes an X.509 certificate or CSR that is to be created, as an alternative to using ASN.1.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CertificateConfig

Returns a new instance of CertificateConfig.



752
753
754
# File 'lib/google/apis/privateca_v1/classes.rb', line 752

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#public_keyGoogle::Apis::PrivatecaV1::PublicKey

A PublicKey describes a public key. Corresponds to the JSON property publicKey



732
733
734
# File 'lib/google/apis/privateca_v1/classes.rb', line 732

def public_key
  @public_key
end

#subject_configGoogle::Apis::PrivatecaV1::SubjectConfig

These values are used to create the distinguished name and subject alternative name fields in an X.509 certificate. Corresponds to the JSON property subjectConfig



738
739
740
# File 'lib/google/apis/privateca_v1/classes.rb', line 738

def subject_config
  @subject_config
end

#subject_key_idGoogle::Apis::PrivatecaV1::CertificateConfigKeyId

A KeyId identifies a specific public key, usually by hashing the public key. Corresponds to the JSON property subjectKeyId



743
744
745
# File 'lib/google/apis/privateca_v1/classes.rb', line 743

def subject_key_id
  @subject_key_id
end

#x509_configGoogle::Apis::PrivatecaV1::X509Parameters

An X509Parameters is used to describe certain fields of an X.509 certificate, such as the key usage fields, fields specific to CA certificates, certificate policy extensions and custom extensions. Corresponds to the JSON property x509Config



750
751
752
# File 'lib/google/apis/privateca_v1/classes.rb', line 750

def x509_config
  @x509_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



757
758
759
760
761
762
# File 'lib/google/apis/privateca_v1/classes.rb', line 757

def update!(**args)
  @public_key = args[:public_key] if args.key?(:public_key)
  @subject_config = args[:subject_config] if args.key?(:subject_config)
  @subject_key_id = args[:subject_key_id] if args.key?(:subject_key_id)
  @x509_config = args[:x509_config] if args.key?(:x509_config)
end