Class: Google::Apis::PrivatecaV1::CertificateIdentityConstraints

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/privateca_v1/classes.rb,
lib/google/apis/privateca_v1/representations.rb,
lib/google/apis/privateca_v1/representations.rb

Overview

Describes constraints on a Certificate's Subject and SubjectAltNames.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CertificateIdentityConstraints

Returns a new instance of CertificateIdentityConstraints.



947
948
949
# File 'lib/google/apis/privateca_v1/classes.rb', line 947

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_subject_alt_names_passthroughBoolean Also known as: allow_subject_alt_names_passthrough?

Required. If this is true, the SubjectAltNames extension may be copied from a certificate request into the signed certificate. Otherwise, the requested SubjectAltNames will be discarded. Corresponds to the JSON property allowSubjectAltNamesPassthrough

Returns:

  • (Boolean)


917
918
919
# File 'lib/google/apis/privateca_v1/classes.rb', line 917

def allow_subject_alt_names_passthrough
  @allow_subject_alt_names_passthrough
end

#allow_subject_passthroughBoolean Also known as: allow_subject_passthrough?

Required. If this is true, the Subject field may be copied from a certificate request into the signed certificate. Otherwise, the requested Subject will be discarded. Corresponds to the JSON property allowSubjectPassthrough

Returns:

  • (Boolean)


925
926
927
# File 'lib/google/apis/privateca_v1/classes.rb', line 925

def allow_subject_passthrough
  @allow_subject_passthrough
end

#cel_expressionGoogle::Apis::PrivatecaV1::Expr

Represents a textual expression in the Common Expression Language (CEL) syntax. CEL is a C-like expression language. The syntax and semantics of CEL are documented at https://github.com/google/cel-spec. Example (Comparison): title: "Summary size limit" description: "Determines if a summary is less than 100 chars" expression: "document.summary.size() < 100" Example (Equality): title: " Requestor is owner" description: "Determines if requestor is the document owner" expression: "document.owner == request.auth.claims.email" Example ( Logic): title: "Public documents" description: "Determine whether the document should be publicly visible" expression: "document.type != 'private' && document.type != 'internal'" Example (Data Manipulation): title: "Notification string" description: "Create a notification string with a timestamp." expression: "'New message received at ' + string(document.create_time)" The exact variables and functions that may be referenced within an expression are determined by the service that evaluates it. See the service documentation for additional information. Corresponds to the JSON property celExpression



945
946
947
# File 'lib/google/apis/privateca_v1/classes.rb', line 945

def cel_expression
  @cel_expression
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



952
953
954
955
956
# File 'lib/google/apis/privateca_v1/classes.rb', line 952

def update!(**args)
  @allow_subject_alt_names_passthrough = args[:allow_subject_alt_names_passthrough] if args.key?(:allow_subject_alt_names_passthrough)
  @allow_subject_passthrough = args[:allow_subject_passthrough] if args.key?(:allow_subject_passthrough)
  @cel_expression = args[:cel_expression] if args.key?(:cel_expression)
end