Class: Google::Apis::PrivatecaV1::KeyUsageOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/privateca_v1/classes.rb,
lib/google/apis/privateca_v1/representations.rb,
lib/google/apis/privateca_v1/representations.rb

Overview

KeyUsage.KeyUsageOptions corresponds to the key usage values described in https://tools.ietf.org/html/rfc5280#section-4.2.1.3.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ KeyUsageOptions

Returns a new instance of KeyUsageOptions.



1621
1622
1623
# File 'lib/google/apis/privateca_v1/classes.rb', line 1621

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cert_signBoolean Also known as: cert_sign?

The key may be used to sign certificates. Corresponds to the JSON property certSign

Returns:

  • (Boolean)


1569
1570
1571
# File 'lib/google/apis/privateca_v1/classes.rb', line 1569

def cert_sign
  @cert_sign
end

#content_commitmentBoolean Also known as: content_commitment?

The key may be used for cryptographic commitments. Note that this may also be referred to as "non-repudiation". Corresponds to the JSON property contentCommitment

Returns:

  • (Boolean)


1576
1577
1578
# File 'lib/google/apis/privateca_v1/classes.rb', line 1576

def content_commitment
  @content_commitment
end

#crl_signBoolean Also known as: crl_sign?

The key may be used sign certificate revocation lists. Corresponds to the JSON property crlSign

Returns:

  • (Boolean)


1582
1583
1584
# File 'lib/google/apis/privateca_v1/classes.rb', line 1582

def crl_sign
  @crl_sign
end

#data_enciphermentBoolean Also known as: data_encipherment?

The key may be used to encipher data. Corresponds to the JSON property dataEncipherment

Returns:

  • (Boolean)


1588
1589
1590
# File 'lib/google/apis/privateca_v1/classes.rb', line 1588

def data_encipherment
  @data_encipherment
end

#decipher_onlyBoolean Also known as: decipher_only?

The key may be used to decipher only. Corresponds to the JSON property decipherOnly

Returns:

  • (Boolean)


1594
1595
1596
# File 'lib/google/apis/privateca_v1/classes.rb', line 1594

def decipher_only
  @decipher_only
end

#digital_signatureBoolean Also known as: digital_signature?

The key may be used for digital signatures. Corresponds to the JSON property digitalSignature

Returns:

  • (Boolean)


1600
1601
1602
# File 'lib/google/apis/privateca_v1/classes.rb', line 1600

def digital_signature
  @digital_signature
end

#encipher_onlyBoolean Also known as: encipher_only?

The key may be used to encipher only. Corresponds to the JSON property encipherOnly

Returns:

  • (Boolean)


1606
1607
1608
# File 'lib/google/apis/privateca_v1/classes.rb', line 1606

def encipher_only
  @encipher_only
end

#key_agreementBoolean Also known as: key_agreement?

The key may be used in a key agreement protocol. Corresponds to the JSON property keyAgreement

Returns:

  • (Boolean)


1612
1613
1614
# File 'lib/google/apis/privateca_v1/classes.rb', line 1612

def key_agreement
  @key_agreement
end

#key_enciphermentBoolean Also known as: key_encipherment?

The key may be used to encipher other keys. Corresponds to the JSON property keyEncipherment

Returns:

  • (Boolean)


1618
1619
1620
# File 'lib/google/apis/privateca_v1/classes.rb', line 1618

def key_encipherment
  @key_encipherment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1626
1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
# File 'lib/google/apis/privateca_v1/classes.rb', line 1626

def update!(**args)
  @cert_sign = args[:cert_sign] if args.key?(:cert_sign)
  @content_commitment = args[:content_commitment] if args.key?(:content_commitment)
  @crl_sign = args[:crl_sign] if args.key?(:crl_sign)
  @data_encipherment = args[:data_encipherment] if args.key?(:data_encipherment)
  @decipher_only = args[:decipher_only] if args.key?(:decipher_only)
  @digital_signature = args[:digital_signature] if args.key?(:digital_signature)
  @encipher_only = args[:encipher_only] if args.key?(:encipher_only)
  @key_agreement = args[:key_agreement] if args.key?(:key_agreement)
  @key_encipherment = args[:key_encipherment] if args.key?(:key_encipherment)
end