Class: Google::Apis::PrivatecaV1::NameConstraints

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/privateca_v1/classes.rb,
lib/google/apis/privateca_v1/representations.rb,
lib/google/apis/privateca_v1/representations.rb

Overview

Describes the X.509 name constraints extension, per https://tools.ietf.org/ html/rfc5280#section-4.2.1.10

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NameConstraints

Returns a new instance of NameConstraints.



2033
2034
2035
# File 'lib/google/apis/privateca_v1/classes.rb', line 2033

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#criticalBoolean Also known as: critical?

Indicates whether or not the name constraints are marked critical. Corresponds to the JSON property critical

Returns:

  • (Boolean)


1972
1973
1974
# File 'lib/google/apis/privateca_v1/classes.rb', line 1972

def critical
  @critical
end

#excluded_dns_namesArray<String>

Contains excluded DNS names. Any DNS name that can be constructed by simply adding zero or more labels to the left-hand side of the name satisfies the name constraint. For example, example.com, www.example.com, www.sub. example.com would satisfy example.com while example1.com does not. Corresponds to the JSON property excludedDnsNames

Returns:

  • (Array<String>)


1981
1982
1983
# File 'lib/google/apis/privateca_v1/classes.rb', line 1981

def excluded_dns_names
  @excluded_dns_names
end

#excluded_email_addressesArray<String>

Contains the excluded email addresses. The value can be a particular email address, a hostname to indicate all email addresses on that host or a domain with a leading period (e.g. .example.com) to indicate all email addresses in that domain. Corresponds to the JSON property excludedEmailAddresses

Returns:

  • (Array<String>)


1989
1990
1991
# File 'lib/google/apis/privateca_v1/classes.rb', line 1989

def excluded_email_addresses
  @excluded_email_addresses
end

#excluded_ip_rangesArray<String>

Contains the excluded IP ranges. For IPv4 addresses, the ranges are expressed using CIDR notation as specified in RFC 4632. For IPv6 addresses, the ranges are expressed in similar encoding as IPv4 addresses. Corresponds to the JSON property excludedIpRanges

Returns:

  • (Array<String>)


1996
1997
1998
# File 'lib/google/apis/privateca_v1/classes.rb', line 1996

def excluded_ip_ranges
  @excluded_ip_ranges
end

#excluded_urisArray<String>

Contains the excluded URIs that apply to the host part of the name. The value can be a hostname or a domain with a leading period (like .example.com) Corresponds to the JSON property excludedUris

Returns:

  • (Array<String>)


2002
2003
2004
# File 'lib/google/apis/privateca_v1/classes.rb', line 2002

def excluded_uris
  @excluded_uris
end

#permitted_dns_namesArray<String>

Contains permitted DNS names. Any DNS name that can be constructed by simply adding zero or more labels to the left-hand side of the name satisfies the name constraint. For example, example.com, www.example.com, www.sub. example.com would satisfy example.com while example1.com does not. Corresponds to the JSON property permittedDnsNames

Returns:

  • (Array<String>)


2010
2011
2012
# File 'lib/google/apis/privateca_v1/classes.rb', line 2010

def permitted_dns_names
  @permitted_dns_names
end

#permitted_email_addressesArray<String>

Contains the permitted email addresses. The value can be a particular email address, a hostname to indicate all email addresses on that host or a domain with a leading period (e.g. .example.com) to indicate all email addresses in that domain. Corresponds to the JSON property permittedEmailAddresses

Returns:

  • (Array<String>)


2018
2019
2020
# File 'lib/google/apis/privateca_v1/classes.rb', line 2018

def permitted_email_addresses
  @permitted_email_addresses
end

#permitted_ip_rangesArray<String>

Contains the permitted IP ranges. For IPv4 addresses, the ranges are expressed using CIDR notation as specified in RFC 4632. For IPv6 addresses, the ranges are expressed in similar encoding as IPv4 addresses. Corresponds to the JSON property permittedIpRanges

Returns:

  • (Array<String>)


2025
2026
2027
# File 'lib/google/apis/privateca_v1/classes.rb', line 2025

def permitted_ip_ranges
  @permitted_ip_ranges
end

#permitted_urisArray<String>

Contains the permitted URIs that apply to the host part of the name. The value can be a hostname or a domain with a leading period (like .example.com) Corresponds to the JSON property permittedUris

Returns:

  • (Array<String>)


2031
2032
2033
# File 'lib/google/apis/privateca_v1/classes.rb', line 2031

def permitted_uris
  @permitted_uris
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2038
2039
2040
2041
2042
2043
2044
2045
2046
2047
2048
# File 'lib/google/apis/privateca_v1/classes.rb', line 2038

def update!(**args)
  @critical = args[:critical] if args.key?(:critical)
  @excluded_dns_names = args[:excluded_dns_names] if args.key?(:excluded_dns_names)
  @excluded_email_addresses = args[:excluded_email_addresses] if args.key?(:excluded_email_addresses)
  @excluded_ip_ranges = args[:excluded_ip_ranges] if args.key?(:excluded_ip_ranges)
  @excluded_uris = args[:excluded_uris] if args.key?(:excluded_uris)
  @permitted_dns_names = args[:permitted_dns_names] if args.key?(:permitted_dns_names)
  @permitted_email_addresses = args[:permitted_email_addresses] if args.key?(:permitted_email_addresses)
  @permitted_ip_ranges = args[:permitted_ip_ranges] if args.key?(:permitted_ip_ranges)
  @permitted_uris = args[:permitted_uris] if args.key?(:permitted_uris)
end