Class: Google::Apis::PrivatecaV1::RelativeDistinguishedName
- Inherits:
-
Object
- Object
- Google::Apis::PrivatecaV1::RelativeDistinguishedName
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/privateca_v1/classes.rb,
lib/google/apis/privateca_v1/representations.rb,
lib/google/apis/privateca_v1/representations.rb
Overview
RelativeDistinguishedName specifies a relative distinguished name which will be used to build a distinguished name.
Instance Attribute Summary collapse
-
#attributes ⇒ Array<Google::Apis::PrivatecaV1::AttributeTypeAndValue>
Attributes describes the attribute value assertions in the RDN.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RelativeDistinguishedName
constructor
A new instance of RelativeDistinguishedName.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RelativeDistinguishedName
Returns a new instance of RelativeDistinguishedName.
2372 2373 2374 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 2372 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attributes ⇒ Array<Google::Apis::PrivatecaV1::AttributeTypeAndValue>
Attributes describes the attribute value assertions in the RDN.
Corresponds to the JSON property attributes
2370 2371 2372 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 2370 def attributes @attributes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2377 2378 2379 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 2377 def update!(**args) @attributes = args[:attributes] if args.key?(:attributes) end |