Class: Google::Apis::PrivatecaV1::RevokedCertificate
- Inherits:
-
Object
- Object
- Google::Apis::PrivatecaV1::RevokedCertificate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/privateca_v1/classes.rb,
lib/google/apis/privateca_v1/representations.rb,
lib/google/apis/privateca_v1/representations.rb
Overview
Describes a revoked Certificate.
Instance Attribute Summary collapse
-
#certificate ⇒ String
The resource name for the Certificate in the format
projects/*/locations/*/ caPools/*/certificates/*. -
#hex_serial_number ⇒ String
The serial number of the Certificate.
-
#revocation_reason ⇒ String
The reason the Certificate was revoked.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RevokedCertificate
constructor
A new instance of RevokedCertificate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RevokedCertificate
Returns a new instance of RevokedCertificate.
2461 2462 2463 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 2461 def initialize(**args) update!(**args) end |
Instance Attribute Details
#certificate ⇒ String
The resource name for the Certificate in the format projects/*/locations/*/
caPools/*/certificates/*.
Corresponds to the JSON property certificate
2449 2450 2451 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 2449 def certificate @certificate end |
#hex_serial_number ⇒ String
The serial number of the Certificate.
Corresponds to the JSON property hexSerialNumber
2454 2455 2456 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 2454 def hex_serial_number @hex_serial_number end |
#revocation_reason ⇒ String
The reason the Certificate was revoked.
Corresponds to the JSON property revocationReason
2459 2460 2461 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 2459 def revocation_reason @revocation_reason end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2466 2467 2468 2469 2470 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 2466 def update!(**args) @certificate = args[:certificate] if args.key?(:certificate) @hex_serial_number = args[:hex_serial_number] if args.key?(:hex_serial_number) @revocation_reason = args[:revocation_reason] if args.key?(:revocation_reason) end |