Class: Google::Apis::PrivatecaV1::RsaKeyType
- Inherits:
-
Object
- Object
- Google::Apis::PrivatecaV1::RsaKeyType
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/privateca_v1/classes.rb,
lib/google/apis/privateca_v1/representations.rb,
lib/google/apis/privateca_v1/representations.rb
Overview
Describes an RSA key that may be used in a Certificate issued from a CaPool.
Instance Attribute Summary collapse
-
#max_modulus_size ⇒ Fixnum
Optional.
-
#min_modulus_size ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RsaKeyType
constructor
A new instance of RsaKeyType.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RsaKeyType
Returns a new instance of RsaKeyType.
2466 2467 2468 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 2466 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_modulus_size ⇒ Fixnum
Optional. The maximum allowed RSA modulus size (inclusive), in bits. If this
is not set, or if set to zero, the service will not enforce an explicit upper
bound on RSA modulus sizes.
Corresponds to the JSON property maxModulusSize
2457 2458 2459 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 2457 def max_modulus_size @max_modulus_size end |
#min_modulus_size ⇒ Fixnum
Optional. The minimum allowed RSA modulus size (inclusive), in bits. If this
is not set, or if set to zero, the service-level min RSA modulus size will
continue to apply.
Corresponds to the JSON property minModulusSize
2464 2465 2466 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 2464 def min_modulus_size @min_modulus_size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2471 2472 2473 2474 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 2471 def update!(**args) @max_modulus_size = args[:max_modulus_size] if args.key?(:max_modulus_size) @min_modulus_size = args[:min_modulus_size] if args.key?(:min_modulus_size) end |