Class: Google::Apis::PrivatecaV1::Subject

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/privateca_v1/classes.rb,
lib/google/apis/privateca_v1/representations.rb,
lib/google/apis/privateca_v1/representations.rb

Overview

Subject describes parts of a distinguished name that, in turn, describes the subject of the certificate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Subject

Returns a new instance of Subject.



2644
2645
2646
# File 'lib/google/apis/privateca_v1/classes.rb', line 2644

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#common_nameString

The "common name" of the subject. Corresponds to the JSON property commonName

Returns:

  • (String)


2602
2603
2604
# File 'lib/google/apis/privateca_v1/classes.rb', line 2602

def common_name
  @common_name
end

#country_codeString

The country code of the subject. Corresponds to the JSON property countryCode

Returns:

  • (String)


2607
2608
2609
# File 'lib/google/apis/privateca_v1/classes.rb', line 2607

def country_code
  @country_code
end

#localityString

The locality or city of the subject. Corresponds to the JSON property locality

Returns:

  • (String)


2612
2613
2614
# File 'lib/google/apis/privateca_v1/classes.rb', line 2612

def locality
  @locality
end

#organizationString

The organization of the subject. Corresponds to the JSON property organization

Returns:

  • (String)


2617
2618
2619
# File 'lib/google/apis/privateca_v1/classes.rb', line 2617

def organization
  @organization
end

#organizational_unitString

The organizational_unit of the subject. Corresponds to the JSON property organizationalUnit

Returns:

  • (String)


2622
2623
2624
# File 'lib/google/apis/privateca_v1/classes.rb', line 2622

def organizational_unit
  @organizational_unit
end

#postal_codeString

The postal code of the subject. Corresponds to the JSON property postalCode

Returns:

  • (String)


2627
2628
2629
# File 'lib/google/apis/privateca_v1/classes.rb', line 2627

def postal_code
  @postal_code
end

#provinceString

The province, territory, or regional state of the subject. Corresponds to the JSON property province

Returns:

  • (String)


2632
2633
2634
# File 'lib/google/apis/privateca_v1/classes.rb', line 2632

def province
  @province
end

#rdn_sequenceArray<Google::Apis::PrivatecaV1::RelativeDistinguishedName>

This field can be used in place of the named subject fields. Corresponds to the JSON property rdnSequence



2637
2638
2639
# File 'lib/google/apis/privateca_v1/classes.rb', line 2637

def rdn_sequence
  @rdn_sequence
end

#street_addressString

The street address of the subject. Corresponds to the JSON property streetAddress

Returns:

  • (String)


2642
2643
2644
# File 'lib/google/apis/privateca_v1/classes.rb', line 2642

def street_address
  @street_address
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2649
2650
2651
2652
2653
2654
2655
2656
2657
2658
2659
# File 'lib/google/apis/privateca_v1/classes.rb', line 2649

def update!(**args)
  @common_name = args[:common_name] if args.key?(:common_name)
  @country_code = args[:country_code] if args.key?(:country_code)
  @locality = args[:locality] if args.key?(:locality)
  @organization = args[:organization] if args.key?(:organization)
  @organizational_unit = args[:organizational_unit] if args.key?(:organizational_unit)
  @postal_code = args[:postal_code] if args.key?(:postal_code)
  @province = args[:province] if args.key?(:province)
  @rdn_sequence = args[:rdn_sequence] if args.key?(:rdn_sequence)
  @street_address = args[:street_address] if args.key?(:street_address)
end