Class: Google::Apis::PrivatecaV1::SubjectAltNames

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/privateca_v1/classes.rb,
lib/google/apis/privateca_v1/representations.rb,
lib/google/apis/privateca_v1/representations.rb

Overview

SubjectAltNames corresponds to a more modern way of listing what the asserted identity is in a certificate (i.e., compared to the "common name" in the distinguished name).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubjectAltNames

Returns a new instance of SubjectAltNames.



2669
2670
2671
# File 'lib/google/apis/privateca_v1/classes.rb', line 2669

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_sansArray<Google::Apis::PrivatecaV1::X509Extension>

Contains additional subject alternative name values. For each custom_san, the value field must contain an ASN.1 encoded UTF8String. Corresponds to the JSON property customSans



2647
2648
2649
# File 'lib/google/apis/privateca_v1/classes.rb', line 2647

def custom_sans
  @custom_sans
end

#dns_namesArray<String>

Contains only valid, fully-qualified host names. Corresponds to the JSON property dnsNames

Returns:

  • (Array<String>)


2652
2653
2654
# File 'lib/google/apis/privateca_v1/classes.rb', line 2652

def dns_names
  @dns_names
end

#email_addressesArray<String>

Contains only valid RFC 2822 E-mail addresses. Corresponds to the JSON property emailAddresses

Returns:

  • (Array<String>)


2657
2658
2659
# File 'lib/google/apis/privateca_v1/classes.rb', line 2657

def email_addresses
  @email_addresses
end

#ip_addressesArray<String>

Contains only valid 32-bit IPv4 addresses or RFC 4291 IPv6 addresses. Corresponds to the JSON property ipAddresses

Returns:

  • (Array<String>)


2662
2663
2664
# File 'lib/google/apis/privateca_v1/classes.rb', line 2662

def ip_addresses
  @ip_addresses
end

#urisArray<String>

Contains only valid RFC 3986 URIs. Corresponds to the JSON property uris

Returns:

  • (Array<String>)


2667
2668
2669
# File 'lib/google/apis/privateca_v1/classes.rb', line 2667

def uris
  @uris
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2674
2675
2676
2677
2678
2679
2680
# File 'lib/google/apis/privateca_v1/classes.rb', line 2674

def update!(**args)
  @custom_sans = args[:custom_sans] if args.key?(:custom_sans)
  @dns_names = args[:dns_names] if args.key?(:dns_names)
  @email_addresses = args[:email_addresses] if args.key?(:email_addresses)
  @ip_addresses = args[:ip_addresses] if args.key?(:ip_addresses)
  @uris = args[:uris] if args.key?(:uris)
end