Class: Google::Apis::PrivatecaV1::SubjectDescription

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/privateca_v1/classes.rb,
lib/google/apis/privateca_v1/representations.rb,
lib/google/apis/privateca_v1/representations.rb

Overview

These values describe fields in an issued X.509 certificate such as the distinguished name, subject alternative names, serial number, and lifetime.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubjectDescription

Returns a new instance of SubjectDescription.



2753
2754
2755
# File 'lib/google/apis/privateca_v1/classes.rb', line 2753

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hex_serial_numberString

The serial number encoded in lowercase hexadecimal. Corresponds to the JSON property hexSerialNumber

Returns:

  • (String)


2720
2721
2722
# File 'lib/google/apis/privateca_v1/classes.rb', line 2720

def hex_serial_number
  @hex_serial_number
end

#lifetimeString

For convenience, the actual lifetime of an issued certificate. Corresponds to the JSON property lifetime

Returns:

  • (String)


2725
2726
2727
# File 'lib/google/apis/privateca_v1/classes.rb', line 2725

def lifetime
  @lifetime
end

#not_after_timeString

The time after which the certificate is expired. Per RFC 5280, the validity period for a certificate is the period of time from not_before_time through not_after_time, inclusive. Corresponds to 'not_before_time' + 'lifetime' - 1 second. Corresponds to the JSON property notAfterTime

Returns:

  • (String)


2733
2734
2735
# File 'lib/google/apis/privateca_v1/classes.rb', line 2733

def not_after_time
  @not_after_time
end

#not_before_timeString

The time at which the certificate becomes valid. Corresponds to the JSON property notBeforeTime

Returns:

  • (String)


2738
2739
2740
# File 'lib/google/apis/privateca_v1/classes.rb', line 2738

def not_before_time
  @not_before_time
end

#subjectGoogle::Apis::PrivatecaV1::Subject

Subject describes parts of a distinguished name that, in turn, describes the subject of the certificate. Corresponds to the JSON property subject



2744
2745
2746
# File 'lib/google/apis/privateca_v1/classes.rb', line 2744

def subject
  @subject
end

#subject_alt_nameGoogle::Apis::PrivatecaV1::SubjectAltNames

SubjectAltNames corresponds to a more modern way of listing what the asserted identity is in a certificate (i.e., compared to the "common name" in the distinguished name). Corresponds to the JSON property subjectAltName



2751
2752
2753
# File 'lib/google/apis/privateca_v1/classes.rb', line 2751

def subject_alt_name
  @subject_alt_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2758
2759
2760
2761
2762
2763
2764
2765
# File 'lib/google/apis/privateca_v1/classes.rb', line 2758

def update!(**args)
  @hex_serial_number = args[:hex_serial_number] if args.key?(:hex_serial_number)
  @lifetime = args[:lifetime] if args.key?(:lifetime)
  @not_after_time = args[:not_after_time] if args.key?(:not_after_time)
  @not_before_time = args[:not_before_time] if args.key?(:not_before_time)
  @subject = args[:subject] if args.key?(:subject)
  @subject_alt_name = args[:subject_alt_name] if args.key?(:subject_alt_name)
end