Class: Google::Apis::PrivatecaV1::X509Extension

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/privateca_v1/classes.rb,
lib/google/apis/privateca_v1/representations.rb,
lib/google/apis/privateca_v1/representations.rb

Overview

An X509Extension specifies an X.509 extension, which may be used in different parts of X.509 objects like certificates, CSRs, and CRLs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ X509Extension

Returns a new instance of X509Extension.



2965
2966
2967
# File 'lib/google/apis/privateca_v1/classes.rb', line 2965

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#criticalBoolean Also known as: critical?

Optional. Indicates whether or not this extension is critical (i.e., if the client does not know how to handle this extension, the client should consider this to be an error). Corresponds to the JSON property critical

Returns:

  • (Boolean)


2950
2951
2952
# File 'lib/google/apis/privateca_v1/classes.rb', line 2950

def critical
  @critical
end

#object_id_propGoogle::Apis::PrivatecaV1::ObjectIdProp

An ObjectId specifies an object identifier (OID). These provide context and describe types in ASN.1 messages. Corresponds to the JSON property objectId



2957
2958
2959
# File 'lib/google/apis/privateca_v1/classes.rb', line 2957

def object_id_prop
  @object_id_prop
end

#valueString

Required. The value of this X.509 extension. Corresponds to the JSON property value NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


2963
2964
2965
# File 'lib/google/apis/privateca_v1/classes.rb', line 2963

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2970
2971
2972
2973
2974
# File 'lib/google/apis/privateca_v1/classes.rb', line 2970

def update!(**args)
  @critical = args[:critical] if args.key?(:critical)
  @object_id_prop = args[:object_id_prop] if args.key?(:object_id_prop)
  @value = args[:value] if args.key?(:value)
end