Class: Google::Apis::PrivatecaV1::X509Parameters
- Inherits:
-
Object
- Object
- Google::Apis::PrivatecaV1::X509Parameters
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/privateca_v1/classes.rb,
lib/google/apis/privateca_v1/representations.rb,
lib/google/apis/privateca_v1/representations.rb
Overview
An X509Parameters is used to describe certain fields of an X.509 certificate, such as the key usage fields, fields specific to CA certificates, certificate policy extensions and custom extensions.
Instance Attribute Summary collapse
-
#additional_extensions ⇒ Array<Google::Apis::PrivatecaV1::X509Extension>
Optional.
-
#aia_ocsp_servers ⇒ Array<String>
Optional.
-
#ca_options ⇒ Google::Apis::PrivatecaV1::CaOptions
Describes the X.509 basic constraints extension, per RFC 5280 section 4.2.1.9 Corresponds to the JSON property
caOptions. -
#key_usage ⇒ Google::Apis::PrivatecaV1::KeyUsage
A KeyUsage describes key usage values that may appear in an X.509 certificate.
-
#name_constraints ⇒ Google::Apis::PrivatecaV1::NameConstraints
Describes the X.509 name constraints extension, per https://tools.ietf.org/ html/rfc5280#section-4.2.1.10 Corresponds to the JSON property
nameConstraints. -
#policy_ids ⇒ Array<Google::Apis::PrivatecaV1::ObjectIdProp>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ X509Parameters
constructor
A new instance of X509Parameters.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ X509Parameters
Returns a new instance of X509Parameters.
3018 3019 3020 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 3018 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_extensions ⇒ Array<Google::Apis::PrivatecaV1::X509Extension>
Optional. Describes custom X.509 extensions.
Corresponds to the JSON property additionalExtensions
2986 2987 2988 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 2986 def additional_extensions @additional_extensions end |
#aia_ocsp_servers ⇒ Array<String>
Optional. Describes Online Certificate Status Protocol (OCSP) endpoint
addresses that appear in the "Authority Information Access" extension in the
certificate.
Corresponds to the JSON property aiaOcspServers
2993 2994 2995 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 2993 def aia_ocsp_servers @aia_ocsp_servers end |
#ca_options ⇒ Google::Apis::PrivatecaV1::CaOptions
Describes the X.509 basic constraints extension, per RFC 5280 section 4.2.1.9
Corresponds to the JSON property caOptions
2999 3000 3001 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 2999 def @ca_options end |
#key_usage ⇒ Google::Apis::PrivatecaV1::KeyUsage
A KeyUsage describes key usage values that may appear in an X.509 certificate.
Corresponds to the JSON property keyUsage
3004 3005 3006 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 3004 def key_usage @key_usage end |
#name_constraints ⇒ Google::Apis::PrivatecaV1::NameConstraints
Describes the X.509 name constraints extension, per https://tools.ietf.org/
html/rfc5280#section-4.2.1.10
Corresponds to the JSON property nameConstraints
3010 3011 3012 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 3010 def name_constraints @name_constraints end |
#policy_ids ⇒ Array<Google::Apis::PrivatecaV1::ObjectIdProp>
Optional. Describes the X.509 certificate policy object identifiers, per https:
//tools.ietf.org/html/rfc5280#section-4.2.1.4.
Corresponds to the JSON property policyIds
3016 3017 3018 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 3016 def policy_ids @policy_ids end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3023 3024 3025 3026 3027 3028 3029 3030 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 3023 def update!(**args) @additional_extensions = args[:additional_extensions] if args.key?(:additional_extensions) @aia_ocsp_servers = args[:aia_ocsp_servers] if args.key?(:aia_ocsp_servers) @ca_options = args[:ca_options] if args.key?(:ca_options) @key_usage = args[:key_usage] if args.key?(:key_usage) @name_constraints = args[:name_constraints] if args.key?(:name_constraints) @policy_ids = args[:policy_ids] if args.key?(:policy_ids) end |