Class: Google::Apis::PrivatecaV1::CertificateDescription
- Inherits:
-
Object
- Object
- Google::Apis::PrivatecaV1::CertificateDescription
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/privateca_v1/classes.rb,
lib/google/apis/privateca_v1/representations.rb,
lib/google/apis/privateca_v1/representations.rb
Overview
A CertificateDescription describes an X.509 certificate or CSR that has been issued, as an alternative to using ASN.1 / X.509.
Instance Attribute Summary collapse
-
#aia_issuing_certificate_urls ⇒ Array<String>
Describes lists of issuer CA certificate URLs that appear in the "Authority Information Access" extension in the certificate.
-
#authority_key_id ⇒ Google::Apis::PrivatecaV1::KeyId
A KeyId identifies a specific public key, usually by hashing the public key.
-
#cert_fingerprint ⇒ Google::Apis::PrivatecaV1::CertificateFingerprint
A group of fingerprints for the x509 certificate.
-
#crl_distribution_points ⇒ Array<String>
Describes a list of locations to obtain CRL information, i.e.
-
#public_key ⇒ Google::Apis::PrivatecaV1::PublicKey
A PublicKey describes a public key.
-
#subject_description ⇒ Google::Apis::PrivatecaV1::SubjectDescription
These values describe fields in an issued X.509 certificate such as the distinguished name, subject alternative names, serial number, and lifetime.
-
#subject_key_id ⇒ Google::Apis::PrivatecaV1::KeyId
A KeyId identifies a specific public key, usually by hashing the public key.
-
#tbs_certificate_digest ⇒ String
The hash of the pre-signed certificate, which will be signed by the CA.
-
#x509_description ⇒ Google::Apis::PrivatecaV1::X509Parameters
An X509Parameters is used to describe certain fields of an X.509 certificate, such as the key usage fields, fields specific to CA certificates, certificate policy extensions and custom extensions.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CertificateDescription
constructor
A new instance of CertificateDescription.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CertificateDescription
Returns a new instance of CertificateDescription.
843 844 845 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 843 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aia_issuing_certificate_urls ⇒ Array<String>
Describes lists of issuer CA certificate URLs that appear in the "Authority
Information Access" extension in the certificate.
Corresponds to the JSON property aiaIssuingCertificateUrls
794 795 796 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 794 def aia_issuing_certificate_urls @aia_issuing_certificate_urls end |
#authority_key_id ⇒ Google::Apis::PrivatecaV1::KeyId
A KeyId identifies a specific public key, usually by hashing the public key.
Corresponds to the JSON property authorityKeyId
799 800 801 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 799 def @authority_key_id end |
#cert_fingerprint ⇒ Google::Apis::PrivatecaV1::CertificateFingerprint
A group of fingerprints for the x509 certificate.
Corresponds to the JSON property certFingerprint
804 805 806 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 804 def cert_fingerprint @cert_fingerprint end |
#crl_distribution_points ⇒ Array<String>
Describes a list of locations to obtain CRL information, i.e. the
DistributionPoint.fullName described by https://tools.ietf.org/html/rfc5280#
section-4.2.1.13
Corresponds to the JSON property crlDistributionPoints
811 812 813 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 811 def crl_distribution_points @crl_distribution_points end |
#public_key ⇒ Google::Apis::PrivatecaV1::PublicKey
A PublicKey describes a public key.
Corresponds to the JSON property publicKey
816 817 818 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 816 def public_key @public_key end |
#subject_description ⇒ Google::Apis::PrivatecaV1::SubjectDescription
These values describe fields in an issued X.509 certificate such as the
distinguished name, subject alternative names, serial number, and lifetime.
Corresponds to the JSON property subjectDescription
822 823 824 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 822 def subject_description @subject_description end |
#subject_key_id ⇒ Google::Apis::PrivatecaV1::KeyId
A KeyId identifies a specific public key, usually by hashing the public key.
Corresponds to the JSON property subjectKeyId
827 828 829 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 827 def subject_key_id @subject_key_id end |
#tbs_certificate_digest ⇒ String
The hash of the pre-signed certificate, which will be signed by the CA.
Corresponds to the TBS Certificate in https://tools.ietf.org/html/rfc5280#
section-4.1.2. The field will always be populated.
Corresponds to the JSON property tbsCertificateDigest
834 835 836 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 834 def tbs_certificate_digest @tbs_certificate_digest end |
#x509_description ⇒ Google::Apis::PrivatecaV1::X509Parameters
An X509Parameters is used to describe certain fields of an X.509 certificate,
such as the key usage fields, fields specific to CA certificates, certificate
policy extensions and custom extensions.
Corresponds to the JSON property x509Description
841 842 843 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 841 def x509_description @x509_description end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
848 849 850 851 852 853 854 855 856 857 858 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 848 def update!(**args) @aia_issuing_certificate_urls = args[:aia_issuing_certificate_urls] if args.key?(:aia_issuing_certificate_urls) @authority_key_id = args[:authority_key_id] if args.key?(:authority_key_id) @cert_fingerprint = args[:cert_fingerprint] if args.key?(:cert_fingerprint) @crl_distribution_points = args[:crl_distribution_points] if args.key?(:crl_distribution_points) @public_key = args[:public_key] if args.key?(:public_key) @subject_description = args[:subject_description] if args.key?(:subject_description) @subject_key_id = args[:subject_key_id] if args.key?(:subject_key_id) @tbs_certificate_digest = args[:tbs_certificate_digest] if args.key?(:tbs_certificate_digest) @x509_description = args[:x509_description] if args.key?(:x509_description) end |