Class: Google::Apis::PrivatecaV1::CertificateTemplate
- Inherits:
-
Object
- Object
- Google::Apis::PrivatecaV1::CertificateTemplate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/privateca_v1/classes.rb,
lib/google/apis/privateca_v1/representations.rb,
lib/google/apis/privateca_v1/representations.rb
Overview
A CertificateTemplate refers to a managed template for certificate issuance.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#identity_constraints ⇒ Google::Apis::PrivatecaV1::CertificateIdentityConstraints
Describes constraints on a Certificate's Subject and SubjectAltNames.
-
#labels ⇒ Hash<String,String>
Optional.
-
#maximum_lifetime ⇒ String
Optional.
-
#name ⇒ String
Identifier.
-
#passthrough_extensions ⇒ Google::Apis::PrivatecaV1::CertificateExtensionConstraints
Describes a set of X.509 extensions that may be part of some certificate issuance controls.
-
#predefined_values ⇒ Google::Apis::PrivatecaV1::X509Parameters
An X509Parameters is used to describe certain fields of an X.509 certificate, such as the key usage fields, fields specific to CA certificates, certificate policy extensions and custom extensions.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CertificateTemplate
constructor
A new instance of CertificateTemplate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CertificateTemplate
Returns a new instance of CertificateTemplate.
1097 1098 1099 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 1097 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time at which this CertificateTemplate was created.
Corresponds to the JSON property createTime
1045 1046 1047 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 1045 def create_time @create_time end |
#description ⇒ String
Optional. A human-readable description of scenarios this template is intended
for.
Corresponds to the JSON property description
1051 1052 1053 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 1051 def description @description end |
#identity_constraints ⇒ Google::Apis::PrivatecaV1::CertificateIdentityConstraints
Describes constraints on a Certificate's Subject and SubjectAltNames.
Corresponds to the JSON property identityConstraints
1056 1057 1058 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 1056 def identity_constraints @identity_constraints end |
#labels ⇒ Hash<String,String>
Optional. Labels with user-defined metadata.
Corresponds to the JSON property labels
1061 1062 1063 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 1061 def labels @labels end |
#maximum_lifetime ⇒ String
Optional. The maximum lifetime allowed for issued Certificates that use this
template. If the issuing CaPool resource's IssuancePolicy specifies a
maximum_lifetime the minimum of the two durations will be the maximum lifetime
for issued Certificates. Note that if the issuing CertificateAuthority expires
before a Certificate's requested maximum_lifetime, the effective lifetime will
be explicitly truncated to match it.
Corresponds to the JSON property maximumLifetime
1071 1072 1073 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 1071 def maximum_lifetime @maximum_lifetime end |
#name ⇒ String
Identifier. The resource name for this CertificateTemplate in the format
projects/*/locations/*/certificateTemplates/*.
Corresponds to the JSON property name
1077 1078 1079 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 1077 def name @name end |
#passthrough_extensions ⇒ Google::Apis::PrivatecaV1::CertificateExtensionConstraints
Describes a set of X.509 extensions that may be part of some certificate
issuance controls.
Corresponds to the JSON property passthroughExtensions
1083 1084 1085 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 1083 def passthrough_extensions @passthrough_extensions end |
#predefined_values ⇒ Google::Apis::PrivatecaV1::X509Parameters
An X509Parameters is used to describe certain fields of an X.509 certificate,
such as the key usage fields, fields specific to CA certificates, certificate
policy extensions and custom extensions.
Corresponds to the JSON property predefinedValues
1090 1091 1092 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 1090 def predefined_values @predefined_values end |
#update_time ⇒ String
Output only. The time at which this CertificateTemplate was updated.
Corresponds to the JSON property updateTime
1095 1096 1097 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 1095 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 1102 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @identity_constraints = args[:identity_constraints] if args.key?(:identity_constraints) @labels = args[:labels] if args.key?(:labels) @maximum_lifetime = args[:maximum_lifetime] if args.key?(:maximum_lifetime) @name = args[:name] if args.key?(:name) @passthrough_extensions = args[:passthrough_extensions] if args.key?(:passthrough_extensions) @predefined_values = args[:predefined_values] if args.key?(:predefined_values) @update_time = args[:update_time] if args.key?(:update_time) end |