Class: Google::Apis::PrivatecaV1::PublishingOptions
- Inherits:
-
Object
- Object
- Google::Apis::PrivatecaV1::PublishingOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/privateca_v1/classes.rb,
lib/google/apis/privateca_v1/representations.rb,
lib/google/apis/privateca_v1/representations.rb
Overview
Options relating to the publication of each CertificateAuthority's CA certificate and CRLs and their inclusion as extensions in issued Certificates. The options set here apply to certificates issued by any CertificateAuthority in the CaPool.
Instance Attribute Summary collapse
-
#encoding_format ⇒ String
Optional.
-
#publish_ca_cert ⇒ Boolean
(also: #publish_ca_cert?)
Optional.
-
#publish_crl ⇒ Boolean
(also: #publish_crl?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PublishingOptions
constructor
A new instance of PublishingOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PublishingOptions
Returns a new instance of PublishingOptions.
2325 2326 2327 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 2325 def initialize(**args) update!(**args) end |
Instance Attribute Details
#encoding_format ⇒ String
Optional. Specifies the encoding format of each CertificateAuthority resource'
s CA certificate and CRLs. If this is omitted, CA certificates and CRLs will
be published in PEM.
Corresponds to the JSON property encodingFormat
2302 2303 2304 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 2302 def encoding_format @encoding_format end |
#publish_ca_cert ⇒ Boolean Also known as: publish_ca_cert?
Optional. When true, publishes each CertificateAuthority's CA certificate and
includes its URL in the "Authority Information Access" X.509 extension in all
issued Certificates. If this is false, the CA certificate will not be
published and the corresponding X.509 extension will not be written in issued
certificates.
Corresponds to the JSON property publishCaCert
2311 2312 2313 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 2311 def publish_ca_cert @publish_ca_cert end |
#publish_crl ⇒ Boolean Also known as: publish_crl?
Optional. When true, publishes each CertificateAuthority's CRL and includes
its URL in the "CRL Distribution Points" X.509 extension in all issued
Certificates. If this is false, CRLs will not be published and the
corresponding X.509 extension will not be written in issued certificates. CRLs
will expire 7 days from their creation. However, we will rebuild daily. CRLs
are also rebuilt shortly after a certificate is revoked.
Corresponds to the JSON property publishCrl
2322 2323 2324 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 2322 def publish_crl @publish_crl end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2330 2331 2332 2333 2334 |
# File 'lib/google/apis/privateca_v1/classes.rb', line 2330 def update!(**args) @encoding_format = args[:encoding_format] if args.key?(:encoding_format) @publish_ca_cert = args[:publish_ca_cert] if args.key?(:publish_ca_cert) @publish_crl = args[:publish_crl] if args.key?(:publish_crl) end |