Class: Google::Apis::PrivatecaV1::X509Extension

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/privateca_v1/classes.rb,
lib/google/apis/privateca_v1/representations.rb,
lib/google/apis/privateca_v1/representations.rb

Overview

An X509Extension specifies an X.509 extension, which may be used in different parts of X.509 objects like certificates, CSRs, and CRLs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ X509Extension

Returns a new instance of X509Extension.



2940
2941
2942
# File 'lib/google/apis/privateca_v1/classes.rb', line 2940

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#criticalBoolean Also known as: critical?

Optional. Indicates whether or not this extension is critical (i.e., if the client does not know how to handle this extension, the client should consider this to be an error). Corresponds to the JSON property critical

Returns:

  • (Boolean)


2925
2926
2927
# File 'lib/google/apis/privateca_v1/classes.rb', line 2925

def critical
  @critical
end

#object_id_propGoogle::Apis::PrivatecaV1::ObjectIdProp

An ObjectId specifies an object identifier (OID). These provide context and describe types in ASN.1 messages. Corresponds to the JSON property objectId



2932
2933
2934
# File 'lib/google/apis/privateca_v1/classes.rb', line 2932

def object_id_prop
  @object_id_prop
end

#valueString

Required. The value of this X.509 extension. Corresponds to the JSON property value NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


2938
2939
2940
# File 'lib/google/apis/privateca_v1/classes.rb', line 2938

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2945
2946
2947
2948
2949
# File 'lib/google/apis/privateca_v1/classes.rb', line 2945

def update!(**args)
  @critical = args[:critical] if args.key?(:critical)
  @object_id_prop = args[:object_id_prop] if args.key?(:object_id_prop)
  @value = args[:value] if args.key?(:value)
end