Class: Google::Apis::PrivatecaV1::X509Parameters

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/privateca_v1/classes.rb,
lib/google/apis/privateca_v1/representations.rb,
lib/google/apis/privateca_v1/representations.rb

Overview

An X509Parameters is used to describe certain fields of an X.509 certificate, such as the key usage fields, fields specific to CA certificates, certificate policy extensions and custom extensions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ X509Parameters

Returns a new instance of X509Parameters.



2993
2994
2995
# File 'lib/google/apis/privateca_v1/classes.rb', line 2993

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_extensionsArray<Google::Apis::PrivatecaV1::X509Extension>

Optional. Describes custom X.509 extensions. Corresponds to the JSON property additionalExtensions



2961
2962
2963
# File 'lib/google/apis/privateca_v1/classes.rb', line 2961

def additional_extensions
  @additional_extensions
end

#aia_ocsp_serversArray<String>

Optional. Describes Online Certificate Status Protocol (OCSP) endpoint addresses that appear in the "Authority Information Access" extension in the certificate. Corresponds to the JSON property aiaOcspServers

Returns:

  • (Array<String>)


2968
2969
2970
# File 'lib/google/apis/privateca_v1/classes.rb', line 2968

def aia_ocsp_servers
  @aia_ocsp_servers
end

#ca_optionsGoogle::Apis::PrivatecaV1::CaOptions

Describes the X.509 basic constraints extension, per RFC 5280 section 4.2.1.9 Corresponds to the JSON property caOptions



2974
2975
2976
# File 'lib/google/apis/privateca_v1/classes.rb', line 2974

def ca_options
  @ca_options
end

#key_usageGoogle::Apis::PrivatecaV1::KeyUsage

A KeyUsage describes key usage values that may appear in an X.509 certificate. Corresponds to the JSON property keyUsage



2979
2980
2981
# File 'lib/google/apis/privateca_v1/classes.rb', line 2979

def key_usage
  @key_usage
end

#name_constraintsGoogle::Apis::PrivatecaV1::NameConstraints

Describes the X.509 name constraints extension, per https://tools.ietf.org/ html/rfc5280#section-4.2.1.10 Corresponds to the JSON property nameConstraints



2985
2986
2987
# File 'lib/google/apis/privateca_v1/classes.rb', line 2985

def name_constraints
  @name_constraints
end

#policy_idsArray<Google::Apis::PrivatecaV1::ObjectIdProp>

Optional. Describes the X.509 certificate policy object identifiers, per https: //tools.ietf.org/html/rfc5280#section-4.2.1.4. Corresponds to the JSON property policyIds



2991
2992
2993
# File 'lib/google/apis/privateca_v1/classes.rb', line 2991

def policy_ids
  @policy_ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2998
2999
3000
3001
3002
3003
3004
3005
# File 'lib/google/apis/privateca_v1/classes.rb', line 2998

def update!(**args)
  @additional_extensions = args[:additional_extensions] if args.key?(:additional_extensions)
  @aia_ocsp_servers = args[:aia_ocsp_servers] if args.key?(:aia_ocsp_servers)
  @ca_options = args[:ca_options] if args.key?(:ca_options)
  @key_usage = args[:key_usage] if args.key?(:key_usage)
  @name_constraints = args[:name_constraints] if args.key?(:name_constraints)
  @policy_ids = args[:policy_ids] if args.key?(:policy_ids)
end